@@ -84,14 +84,14 @@ ndr<-function(r,covar=FALSE,cor_method=1,cor_type=1,min_R=0,min_comm=2,Gamma=1,
   }
   COR[is.na(COR)]<-0
   issymm<-isSymmetric(as.matrix(COR))
-  if (issymm==FALSE){
-    if (mod_mode<4){
-      stop(
-        "If correlation/simmilarity matrix is non-symmetric only InfoMap/Walktrap modularities can be used.",
-        call. = FALSE
-      )
-    }
-  }
+  #if (issymm==FALSE){
+    #if (mod_mode<4){
+    #  stop(
+    #    "If correlation/simmilarity matrix is non-symmetric only InfoMap/Walktrap modularities can be used.",
+    #    call. = FALSE
+    #  )
+    #}
+  #}
   R<-COR^2
   R<-as.data.frame(R)
   colnames(R)<-colnames(r)
@@ -146,17 +146,17 @@ ndr<-function(r,covar=FALSE,cor_method=1,cor_type=1,min_R=0,min_comm=2,Gamma=1,
     modular=switch(
       mod_mode,
       "1"=igraph::cluster_louvain(igraph::graph.adjacency(MTX,
-                                                          mode = "directed", weighted = TRUE, diag = FALSE)),
+                                                          mode = "undirected", weighted = TRUE, diag = FALSE)),
       "2"=igraph::cluster_fast_greedy(igraph::graph.adjacency(as.matrix(MTX),
-                                                              mode = "directed", weighted = TRUE, diag = FALSE)),
+                                                              mode = "undirected", weighted = TRUE, diag = FALSE)),
       "3"=igraph::cluster_leading_eigen(igraph::graph.adjacency(as.matrix(MTX),
-                                                                mode = "directed", weighted = TRUE, diag = FALSE)),
+                                                                mode = "undirected", weighted = TRUE, diag = FALSE)),
       "4"=igraph::cluster_infomap(igraph::graph.adjacency(as.matrix(MTX),
                                                           mode = "directed", weighted = TRUE, diag = FALSE)),
       "5"=igraph::cluster_walktrap(igraph::graph.adjacency(as.matrix(MTX),
                                                            mode = "directed", weighted = TRUE, diag = FALSE)),
       "6"=igraph::cluster_leiden(igraph::graph.adjacency(as.matrix(MTX),
-                                                              mode = "directed", weighted = TRUE, diag = FALSE),
+                                                              mode = "undirected", weighted = TRUE, diag = FALSE),
                                  objective_function = "modularity")
     )
   }
